@@ -7,10 +7,16 @@ use thiserror::Error;
 #[derive(Error, Debug, Diagnostic)]
 pub(crate) enum MitCommitMsgError {
     #[error("expected file path name")]
-    #[diagnostic()]
+    #[diagnostic(
+        url(docsrs),
+        code(mit_commit_msg::errors::mit_commit_msg_error::commit_path_missing)
+    )]
     CommitPathMissing,
     #[error("{0}")]
-    #[diagnostic()]
+    #[diagnostic(
+        url(docsrs),
+        code(mit_commit_msg::errors::mit_commit_msg_error::clipboard)
+    )]
     Clipboard(#[source] Box<dyn error::Error + Sync + Send>),
 }
 
