@@ -20,6 +20,7 @@ async fn main() -> Result<()> {
             Box::new(
                 miette::MietteHandlerOpts::new()
                     .force_graphical(true)
+                    .terminal_links(false)
                     .graphical_theme(GraphicalTheme::unicode_nocolor())
                     .build(),
             )
@@ -34,7 +35,7 @@ async fn main() -> Result<()> {
         Some(path) => Ok(path),
     }
     .map(PathBuf::from)?;
-    let commit_message = CommitMessage::try_from(commit_file_path).into_diagnostic()?;
+    let commit_message = CommitMessage::try_from(commit_file_path)?;
     let current_dir = env::current_dir().into_diagnostic()?;
 
     let toml = external::read_toml(current_dir.clone())?;
